@@ -2,9 +2,9 @@ __title__ = 'Amino.ed'
 __author__ = 'Alert Aigul'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020-2022 Alert'
-__version__ = '2.5.1'
+__version__ = '2.6.3'
 
-from asyncio import get_event_loop
+from asyncio import get_event_loop, sleep, create_task, gather
 from asyncio.events import AbstractEventLoop
 from requests import get
 
@@ -13,6 +13,11 @@ from .community_client import CommunityClient
 from .utils import exceptions, models, types, helpers
 from .websocket import WebSocketClient
 
+from .utils.helpers import *
+from .utils.types import *
+from .utils.models import *
+from .utils.exceptions import *
+
 
 def run_with_client(event_loop: AbstractEventLoop = None, deviceId: str = None):
     async def start(loop, callback):
@@ -24,6 +29,12 @@ def run_with_client(event_loop: AbstractEventLoop = None, deviceId: str = None):
         loop.run_until_complete(start(loop, callback))
     return _start
 
+def run():
+    def start(callback):
+        loop = get_event_loop()
+        loop.run_until_complete(callback())
+    return start
+
 
 __newest__ = get("https://pypi.python.org/pypi/Amino.ed/json").json()["info"]["version"]
 
