@@ -67,7 +67,7 @@ class Account(BaseModel):
     class AdvancedSettings(BaseModel):
         analyticsEnabled: Optional[int]
 
-    extensions:            Optional[Extensions]
+    extensions:            Optional[Extensions] = Extensions()
     advancedSettings:      Optional[AdvancedSettings]
     username:              Optional[str]
     status:                Optional[int]
@@ -98,16 +98,33 @@ class UserProfile(BaseModel):
 
     class Extensions(BaseModel):
         class Style(BaseModel):
+            backgroundColor:     Optional[str]
             backgroundMediaList: Optional[List[List]]
+            
+        class Title(BaseModel):
+            color: Optional[str]
+            title: Optional[str]
 
-        style: Optional[Style]
+        style:              Optional[Style]
+        __disabledStatus__: Optional[int]
+        __disabledTime__:   Optional[int]
+        __disabledLevel__:  Optional[int]
+        hideUserProfile:    Optional[bool]
+        defaultBubbleId:    Optional[str]
+
+        customTitles:                    Optional[List[Title]]
+        coverAnimation:                  Optional[Any]
+        isMemberOfTeamAmino:             Optional[bool]
+        privilegeOfChatInviteRequest:    Optional[int]
+        privilegeOfCommentOnUserProfile: Optional[int]
 
     class InfluencerInfo(BaseModel):
         fansCount:   Optional[int]
         monthlyFee:  Optional[int]
         pinned:      Optional[bool]
         createdTime: Optional[datetime]
-
+        
+    extensions:              Optional[Extensions] = Extensions()
     influencerInfo:          Optional[InfluencerInfo]
     avatarFrame:             Optional[AvatarFrame]
     settings:                Optional[Settings]
@@ -516,7 +533,7 @@ class Thread(BaseModel):
         vvChatJoinType:               Optional[int]
 
     author:             Optional[UserProfile]
-    extensions:         Optional[Extensions]
+    extensions:         Optional[Extensions] = Extensions()
     lastMessageSummary: Optional[LastMessage]
     tipInfo:            Optional[TipInfo]
     userAddedTopicList: Optional[Topic]
@@ -573,7 +590,7 @@ class Message(BaseModel):
         replyMessage:      Optional[Dict]
         replyMessageId:    Optional[str]
 
-    extensions:        Optional[Extensions]
+    extensions:        Optional[Extensions] = Extensions()
     includedInSummary: Optional[bool]
     author:            Optional[UserProfile]
     isHidden:          Optional[bool]
@@ -583,7 +600,7 @@ class Message(BaseModel):
     content:           Optional[str]
     chatBubbleId:      Optional[str]
     clientRefId:       Optional[int]
-    threadId:          Optional[str]
+    chatId:            Optional[str] = Field(alias="threadId")
     createdTime:       Optional[datetime]
     chatBubbleVersion: Optional[int]
     type:              Optional[int]
@@ -613,7 +630,7 @@ class Blog(BaseModel):
 
         status:         Optional[int]
         parentType:     Optional[int]
-        extensions:     Optional[Extensions]
+        extensions:     Optional[Extensions] = Extensions()
         title:          Optional[str]
         createdTime:    Optional[datetime]
         quizQuestionId: Optional[str]
@@ -656,7 +673,7 @@ class Blog(BaseModel):
     viewCount:             Optional[int]
     language:              Optional[str]
     author:                Optional[UserProfile]
-    extensions:            Optional[Extensions]
+    extensions:            Optional[Extensions] = Extensions()
     votesCount:            Optional[int]
     comId:                 Optional[int] = Field(alias="ndcId")
     createdTime:           Optional[datetime]
@@ -687,7 +704,7 @@ class Wiki(BaseModel):
     globalCommentsCount: Optional[int]
     modifiedTime:        Optional[datetime]
     itemId:              Optional[str]
-    extensions:          Optional[Extensions]
+    extensions:          Optional[Extensions] = Extensions()
     votesCount:          Optional[int]
     comId:               Optional[int] = Field(alias="ndcId")
     createdTime:         Optional[datetime]
@@ -817,7 +834,7 @@ class StickerCollection(BaseModel):
     collectionId:        Optional[str]
     description:         Optional[str]
     author:              Optional[UserProfile]
-    extensions:          Optional[Extensions]
+    extensions:          Optional[Extensions] = Extensions()
     createdTime:         Optional[datetime]
     isGloballyAvailable: Optional[bool]
     restrictionInfo:     Optional[RestrictionInfo]
@@ -963,3 +980,14 @@ class Event(BaseModel):
     message:          Optional[Message] = Field(alias="chatMessage")
     alertOption:      Optional[int]
     membershipStatus: Optional[int]
+
+class SID(BaseModel):
+    signature:  Optional[str]
+    prefix:     Optional[str]
+    original:   Optional[str]
+    data:       Optional[dict]
+    version:    Optional[int] = Field(alias="0") # ?
+    userId:     Optional[str] = Field(alias="2")
+    ip:         Optional[str] = Field(alias="4")
+    makeTime:   Optional[int] = Field(alias="5")
+    clientType: Optional[int] = Field(alias="6")
