@@ -44,7 +44,9 @@ class WebSocketClient:
                 if recieved_data["t"] == 1000:
                     self.emitter.emit("message", Event(**recieved_data["o"]))
                 
-                self.emitter.emit("event", recieved_data["o"])
+                self.emitter.emit("event", recieved_data)
+                
+                self.emitter.emit(f"t{recieved_data['t']}", recieved_data["o"])
                 
 
     async def create_connection(self) -> WSConnection:
